@@ -4,17 +4,18 @@ use File::Spec;
 use File::Slurp;
 use Template;
 
-set 'database'     => File::Spec->tmpdir() . '/dancr.db';
-set 'session'      => 'Simple';
-set 'template'     => 'template_toolkit';
-set 'logger'       => 'console';
-set 'log'          => 'debug';
-set 'show_errors'  => 1;
-set 'startup_info' => 1;
-set 'warnings'     => 1;
-set 'username'     => 'admin';
-set 'password'     => 'password';
-set 'layout'       => 'main';
+set 'database' => File::Spec->tmpdir() . '/dancr.db';
+set 'session' => 'Simple';
+set 'template' => 'template_toolkit';
+set 'logger' => 'console';
+set 'log' => 'debug';
+set 'show_errors' => 1;
+set 'access_log' => 1;
+set 'warnings' => 1;
+set 'username' => 'admin';
+set 'password' => 'password';
+
+layout 'main';
 
 my $flash;
 
@@ -47,7 +48,7 @@ sub init_db {
 
 before_template sub {
 	my $tokens = shift;
-
+	
 	$tokens->{'css_url'} = request->base . 'css/style.css';
 	$tokens->{'login_url'} = uri_for('/login');
 	$tokens->{'logout_url'} = uri_for('/logout');
@@ -58,7 +59,7 @@ get '/' => sub {
 	my $sql = 'select id, title, text from entries order by id desc';
 	my $sth = $db->prepare($sql) or die $db->errstr;
 	$sth->execute or die $sth->errstr;
-	template 'show_entries.tt', {
+	template 'show_entries.tt', { 
 		'msg' => get_flash(),
 		'add_entry_url' => uri_for('/add'),
 		'entries' => $sth->fetchall_hashref('id'),
@@ -93,12 +94,12 @@ any ['get', 'post'] => '/login' => sub {
 		else {
 			session 'logged_in' => true;
 			set_flash('You are logged in.');
-			return redirect '/';
+			redirect '/';
 		}
 	}
 
 	# display login form
-	template 'login.tt', {
+	template 'login.tt', { 
 		'err' => $err,
 	};
 
